@@ -21,8 +21,8 @@ namespace torrent {
 
 HashString DhtRouter::zero_id;
 
-DhtRouter::DhtRouter(const Object& cache, const sockaddr* sa) :
-  DhtNode(zero_id, sa), // actual ID is set later
+DhtRouter::DhtRouter(const Object& cache) :
+  DhtNode(zero_id, sa_make_inet_any().get()), // actual ID is set later
   m_server(this),
   m_curToken(random()),
   m_prevToken(random()) {
@@ -52,7 +52,7 @@ DhtRouter::DhtRouter(const Object& cache, const sockaddr* sa) :
     sha.final_c(data());
   }
 
-  LT_LOG_THIS("creating : address:%s", sa_pretty_str(sa).c_str());
+  LT_LOG_THIS("creating", 0);
 
   set_bucket(new DhtBucket(zero_id, ones_id));
   m_routingTable.emplace(bucket()->id_range_end(), bucket());
@@ -100,7 +100,7 @@ DhtRouter::~DhtRouter() {
 
 void
 DhtRouter::start(int port) {
-  LT_LOG_THIS("starting (port:%d)", port);
+  LT_LOG_THIS("starting: port:%d", port);
 
   m_server.start(port);
 
@@ -214,7 +214,18 @@ DhtRouter::contact(const sockaddr* sa, int port) {
   if (!is_active())
     return;
 
-  auto sa_tmp = sa_copy(sa);
+  auto sa_tmp = sa_copy_unmapped(sa);
+
+  if (sa_tmp->sa_family != AF_INET && sa_tmp->sa_family != AF_INET6)
+    throw input_error("DhtRouter::contact() called with non-inet/inet6 address.");
+
+  // Currently only IPv4 is supported.
+  if (sa_tmp->sa_family != AF_INET)
+    return;
+
+  if (sap_is_any(sa_tmp))
+    throw input_error("DhtRouter::contact() called with any address.");
+
   sap_set_port(sa_tmp, port);
 
   m_server.ping(zero_id, sa_tmp.get());
@@ -343,7 +354,7 @@ DhtRouter::store_cache(Object* container) const {
 
 tracker::DhtController::statistics_type
 DhtRouter::get_statistics() const {
-  tracker::DhtController::statistics_type stats(*m_server.upload_throttle_node()->rate(), *m_server.download_throttle_node()->rate());
+  tracker::DhtController::statistics_type stats;
 
   if (!m_server.is_active())
     stats.cycle = 0;
