@@ -2,21 +2,11 @@
 
 #include "socket_stream.h"
 
-#include <cerrno>
-#include <cstdio>
-#include <cstring>
 #include <rak/error_number.h>
 
 namespace torrent {
 
-std::string
-int_to_string(int v) {
-  char buf[20];
-
-  std::snprintf(buf, 20, "%i", v);
-
-  return buf;
-}
+SocketStream::~SocketStream() = default;
 
 uint32_t
 SocketStream::read_stream_throws(void* buf, uint32_t length) {
@@ -60,4 +50,4 @@ SocketStream::write_stream_throws(const void* buf, uint32_t length) {
   return r;
 }
 
-}
+} // namespace torrent
